# Generated by the protocol buffer compiler.  DO NOT EDIT!
# sources: pymammotion/proto/basestation.proto
# plugin: python-betterproto
from dataclasses import dataclass

import betterproto


@dataclass
class RequestBasestationInfoT(betterproto.Message):
    request_type: int = betterproto.uint32_field(1)


@dataclass
class ResponseBasestationInfoT(betterproto.Message):
    system_status: int = betterproto.uint64_field(1)
    app_connect_type: int = betterproto.uint32_field(2)
    ble_rssi: int = betterproto.int32_field(3)
    wifi_rssi: int = betterproto.int32_field(4)
    sats_num: int = betterproto.uint64_field(5)
    lora_scan: int = betterproto.int64_field(6)
    lora_channel: int = betterproto.int64_field(7)
    lora_locid: int = betterproto.int64_field(8)
    lora_netid: int = betterproto.int64_field(9)
    rtk_status: int = betterproto.uint64_field(10)
    lowpower_status: int = betterproto.int32_field(11)
    mqtt_rtk_status: int = betterproto.int32_field(12)
    rtk_channel: int = betterproto.int32_field(13)
    rtk_switch: int = betterproto.int32_field(14)


@dataclass
class AppToBaseMqttRtkT(betterproto.Message):
    rtk_switch: int = betterproto.int32_field(1)
    rtk_url: str = betterproto.string_field(2)
    rtk_port: int = betterproto.int32_field(3)
    rtk_username: str = betterproto.string_field(4)
    rtk_password: str = betterproto.string_field(5)


@dataclass
class BaseToAppMqttRtkT(betterproto.Message):
    rtk_switch_status: int = betterproto.int32_field(1)


@dataclass
class BaseStation(betterproto.Message):
    to_dev: "RequestBasestationInfoT" = betterproto.message_field(
        1, group="BaseStationSubType"
    )
    to_app: "ResponseBasestationInfoT" = betterproto.message_field(
        2, group="BaseStationSubType"
    )
    app_to_base_mqtt_rtk_msg: "AppToBaseMqttRtkT" = betterproto.message_field(
        3, group="BaseStationSubType"
    )
    base_to_app_mqtt_rtk_msg: "BaseToAppMqttRtkT" = betterproto.message_field(
        4, group="BaseStationSubType"
    )
